@@ -6,6 +6,14 @@ function changeAmpersand(str) {
     return str.replace(/&/g,"%26");
 }
 
+function getProtocol() {
+    if (utility.getPlatform() == "maemo5") {
+        return "http://";
+    } else {
+        return "https://";
+    }
+}
+
 function rilPopulateListModel(list, listmodel) {
     //listmodel.clear()
     var a = JSON.parse(list)["list"];
@@ -33,7 +41,7 @@ function rilDownloadList() {
     var xhr = new XMLHttpRequest;
     var params = rilGetParams();
     //console.log(params);
-    var url="http://readitlaterlist.com/v2/get";
+    var url= getProtocol() + "readitlaterlist.com/v2/get";
     var since=Storage.getSetting("rilLastUpdate");
     params = params + "&state=unread"
     if (since!="Unknown") {
@@ -89,7 +97,7 @@ function rilDownloadRilArticle(articleUrl) {
     var xhr = new XMLHttpRequest;
 
     var params = "apikey=" + Storage.getSetting("apikey")+"&images=1&url="+articleUrl;
-    var url="http://text.readitlaterlist.com/v2/text";
+    var url= getProtocol() + "text.readitlaterlist.com/v2/text";
     xhr.open("POST", url);
     xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
     xhr.setRequestHeader("Content-length", params.length);
@@ -132,7 +140,7 @@ function sendReq(url, params) {
 
 function rilDownloadApiKey() {
     var xhr = new XMLHttpRequest;
-    var url = "http://feedingit.marcoz.org/lukija.apikey"
+    var url = "http://feedingit.marcoz.org/lukija.apikey?platform=" + utility.getPlatform();
     xhr.open("GET", url);
 
     xhr.onreadystatechange = function() {
@@ -173,7 +181,7 @@ function rilGet(listmodel) {
 function rilMarkAsRead(item) {
     // Mark an item as read. Parameter should be the URL of the item
     var params = rilGetParams();
-    var url = "http://readitlaterlist.com/v2/send";
+    var url = getProtocol() + "readitlaterlist.com/v2/send";
     
     var req = {"0" : { "url" : item } };
     var jreq = JSON.stringify(req);
@@ -191,7 +199,7 @@ function updateList() {
 
 function checkLogin() {
     var params = rilGetParams();
-    var url = "http://readitlaterlist.com/v2/auth"
+    var url = getProtocol() + "readitlaterlist.com/v2/auth"
     //console.log(params)
 
     var status = sendReq(url,params);
