@@ -50,7 +50,7 @@ function setSetting(setting, value) {
 }
 
 function getRilArticle(url) {
-   var db = getDatabase(); //openDatabaseSync("EZRil", "1.0", "StorageDatabase", 1000000);
+   var db = getDatabase();
    var res="";
    db.transaction(function(tx) {
      var rs = tx.executeSql('SELECT article FROM rilArticles WHERE url=?;', [url,]);
@@ -64,8 +64,22 @@ function getRilArticle(url) {
   return res
 }
 
+function getRilTitle(url) {
+   var db = getDatabase();
+   var res="";
+   db.transaction(function(tx) {
+     var rs = tx.executeSql('SELECT title FROM rilArticles WHERE url=?;', [url,]);
+     if (rs.rows.length > 0) {
+          res = rs.rows.item(0).title;
+     } else {
+         res = "Unknown";
+     }
+  })
+  return res
+}
+
 function getDownloadedStatus(url) {
-   var db = getDatabase(); //openDatabaseSync("EZRil", "1.0", "StorageDatabase", 1000000);
+   var db = getDatabase();
    var res="";
    db.transaction(function(tx) {
      var rs = tx.executeSql('SELECT downloaded FROM rilArticles WHERE url=?;', [url,]);
@@ -135,31 +149,50 @@ function updateRilArticle(url, article) {
    return res;
 }
 
-function getRilList() {
+function getRilList(listmodel) {
     var db = getDatabase();
     var xml;
     db.transaction(function(tx) {
-                        var rs = tx.executeSql('SELECT url,title,unread,downloaded FROM rilArticles');
+                        var rs = tx.executeSql('SELECT url,title,unread,downloaded FROM rilArticles ORDER BY updateTime');
                         //console.log(rs.rowsAffected);
                         if (rs.rows.length > 0) {
-                            xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?><xml>"
-                            for(var i = 0; i < rs.rows.length; i++) {
-                                xml += "<article>";
-                                xml += "<title>"+rs.rows.item(i).title+"</title>";
-                                xml += "<articleid>"+rs.rows.item(i).url+"</articleid>";
-                                xml += "<unread>"+rs.rows.item(i).unread+"</unread>";
-                                xml += "<downloaded>"+rs.rows.item(i).downloaded+"</downloaded>"
-                                xml += "</article>";
+                            //listmodel.clear();
+                            var indexedList = new Array();
+                            for(var i=0; i<listmodel.count; i++) {
+                                indexedList[i] = listmodel.get(i).articleid;
+                                //console.log(listmodel.get(i).articleid);
+                                //indexedList[listmodel.get(i).url] = i;
+
                             }
-                            xml += "</xml>";
+                            //console.log(indexedList)
+
+                            //xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?><xml>"
+                            for(var i = 0; i < rs.rows.length; i++) {
+                                var index = indexedList.indexOf(rs.rows.item(i).url);
+                                //console.log(rs.rows.item(i).url + " " + index)
+                                if (index > -1) {
+                                    listmodel.setProperty(index, "unread", rs.rows.item(i).unread);
+                                } else {
+                                    listmodel.append({title: rs.rows.item(i).title, articleid: rs.rows.item(i).url, unread: rs.rows.item(i).unread, downloaded: rs.rows.item(i).downloaded});
+                                }
+//                                xml += "<article>";
+//                                xml += "<title>"+rs.rows.item(i).title+"</title>";
+//                                xml += "<articleid>"+rs.rows.item(i).url+"</articleid>";
+//                                xml += "<unread>"+rs.rows.item(i).unread+"</unread>";
+//                                xml += "<downloaded>"+rs.rows.item(i).downloaded+"</downloaded>"
+//                                xml += "</article>";
+                            }
+                            //xml += "</xml>";
                         } else {
-                            xml = "Error";
+                            //xml = "Error";
                         }
                    }
    );
-   return xml;
+   return listmodel;
 }
 
+
+
 function resetAll() {
     var db = getDatabase();
     db.transaction(
